from PyOfficeRobot.api import chat
from PyOfficeRobot.api import file
from PyOfficeRobot.lib.CONST import SPLIT_LINE

print(SPLIT_LINE)
print('【PyOfficeRobot，微信机器人】')
print('【全部功能】：https://www.python-office.com/office/robot.html')
print(SPLIT_LINE)